@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Type
+from typing import Any, Dict, Mapping, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -36,7 +36,7 @@ __all__ = ("FinSpaceDataClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -52,7 +52,7 @@ class Exceptions:
 
 class FinSpaceDataClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/finspace-data.html#FinSpaceData.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
     """
 
@@ -68,7 +68,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#can_paginate)
         """
 
@@ -78,29 +78,29 @@ class FinSpaceDataClient(BaseClient):
         datasetId: str,
         changeType: ChangeTypeType,
         sourceType: Literal["S3"],
-        sourceParams: Dict[str, str],
+        sourceParams: Mapping[str, str],
         formatType: FormatTypeType = None,
-        formatParams: Dict[str, str] = None,
-        tags: Dict[str, str] = None
+        formatParams: Mapping[str, str] = None,
+        tags: Mapping[str, str] = None
     ) -> CreateChangesetResponseTypeDef:
         """
         Creates a new changeset in a FinSpace dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_changeset)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#generate_presigned_url)
         """
 
@@ -110,7 +110,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Request programmatic credentials to use with Habanero SDK.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_programmatic_access_credentials)
         """
 
@@ -121,6 +121,6 @@ class FinSpaceDataClient(BaseClient):
         A temporary Amazon S3 location to copy your files from a source location to
         stage or use as a scratch space in Habanero notebook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_working_location)
         """
